package Protocol::ACME::Challenge;

use strict;
use warnings;

=head1 NAME

Protocol::ACME::Challenge - Empty base class for ACME Challenges


=cut

our $VERSION = '0.11';


1;
